==> owncloud-10.0.7.tgz: owncloud/core/l10n/cy_GB.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Sul",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "Sun." : "Sul.",
    "Mon." : "Llun.",
    "Tue." : "Maw.",
    "Wed." : "Mer.",
    "Thu." : "Iau.",
    "Fri." : "Gwe.",
    "Sat." : "Sad.",
    "January" : "Ionawr",
    "February" : "Chwefror",
    "March" : "Mawrth",
    "April" : "Ebrill",
    "May" : "Mai",
    "June" : "Mehefin",
    "July" : "Gorffennaf",
    "August" : "Awst",
    "September" : "Medi",
    "October" : "Hydref",
    "November" : "Tachwedd",
    "December" : "Rhagfyr",
    "Jan." : "Ion.",
    "Feb." : "Chwe.",
    "Mar." : "Maw.",
    "Apr." : "Ebr.",
    "May." : "Mai.",
    "Jun." : "Meh.",
    "Jul." : "Gor.",
    "Aug." : "Aws.",
    "Sep." : "Med.",
    "Oct." : "Hyd.",
    "Nov." : "Tach.",
    "Dec." : "Rhag.",
    "Settings" : "Gosodiadau",
    "Saving..." : "Yn cadw...",
    "seconds ago" : "eiliad yn ôl",
    "No" : "Na",
    "Yes" : "Ie",
    "Choose" : "Dewisiwch",
    "Ok" : "Iawn",
    "Cancel" : "Diddymu",
    "Shared" : "Rhannwyd",
    "Error" : "Gwall",
    "Error while sharing" : "Gwall wrth rannu",
    "Error while unsharing" : "Gwall wrth ddad-rannu",
    "Set expiration date" : "Gosod dyddiad dod i ben",
    "Expiration date" : "Dyddiad dod i ben",
    "Edit" : "Golygu",
    "Remove" : "Gwaredu",
    "Password" : "Cyfrinair",
    "Name" : "Enw",
    "Save" : "Cadw",
    "Sending ..." : "Yn anfon ...",
    "Email sent" : "Anfonwyd yr e-bost",
    "Email link to person" : "E-bostio dolen at berson",
    "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
    "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
    "group" : "grŵp",
    "Unshare" : "Dad-rannu",
    "can edit" : "yn gallu golygu",
    "create" : "creu",
    "delete" : "dileu",
    "access control" : "rheolaeth mynediad",
    "Share" : "Rhannu",
    "Resharing is not allowed" : "Does dim hawl ail-rannu",
    "Warning" : "Rhybudd",
    "Delete" : "Dileu",
    "Rename" : "Ailenwi",
    "The object type is not specified." : "Nid yw'r math o wrthrych wedi cael ei nodi.",
    "Add" : "Ychwanegu",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Methodd y diweddariad. Adroddwch y mater hwn i <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">gymuned ownCloud</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Roedd y diweddariad yn llwyddiannus. Cewch eich ailgyfeirio i ownCloud nawr.",
    "Personal" : "Personol",
    "Users" : "Defnyddwyr",
    "Apps" : "Pecynnau",
    "Admin" : "Gweinyddu",
    "Help" : "Cymorth",
    "Access forbidden" : "Mynediad wedi'i wahardd",
    "Create an <strong>admin account</strong>" : "Crewch <strong>gyfrif gweinyddol</strong>",
    "Username" : "Enw defnyddiwr",
    "Data folder" : "Plygell data",
    "Configure the database" : "Cyflunio'r gronfa ddata",
    "Database user" : "Defnyddiwr cronfa ddata",
    "Database password" : "Cyfrinair cronfa ddata",
    "Database name" : "Enw cronfa ddata",
    "Database tablespace" : "Tablespace cronfa ddata",
    "Database host" : "Gwesteiwr cronfa ddata",
    "Finish setup" : "Gorffen sefydlu",
    "Log out" : "Allgofnodi",
    "Search" : "Chwilio",
    "Log in" : "Mewngofnodi",
    "Alternative Logins" : "Mewngofnodiadau Amgen",
    "Use the following link to reset your password: {link}" : "Defnyddiwch y ddolen hon i ailosod eich cyfrinair: {link}",
    "New password" : "Cyfrinair newydd",
    "Reset password" : "Ailosod cyfrinair"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");

==> owncloud-10.0.10.tgz: owncloud/core/l10n/cy_GB.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "Sul",
    "Monday" : "Llun",
    "Tuesday" : "Mawrth",
    "Wednesday" : "Mercher",
    "Thursday" : "Iau",
    "Friday" : "Gwener",
    "Saturday" : "Sadwrn",
    "Sun." : "Sul.",
    "Mon." : "Llun.",
    "Tue." : "Maw.",
    "Wed." : "Mer.",
    "Thu." : "Iau.",
    "Fri." : "Gwe.",
    "Sat." : "Sad.",
    "January" : "Ionawr",
    "February" : "Chwefror",
    "March" : "Mawrth",
    "April" : "Ebrill",
    "May" : "Mai",
    "June" : "Mehefin",
    "July" : "Gorffennaf",
    "August" : "Awst",
    "September" : "Medi",
    "October" : "Hydref",
    "November" : "Tachwedd",
    "December" : "Rhagfyr",
    "Jan." : "Ion.",
    "Feb." : "Chwe.",
    "Mar." : "Maw.",
    "Apr." : "Ebr.",
    "May." : "Mai.",
    "Jun." : "Meh.",
    "Jul." : "Gor.",
    "Aug." : "Aws.",
    "Sep." : "Med.",
    "Oct." : "Hyd.",
    "Nov." : "Tach.",
    "Dec." : "Rhag.",
    "Settings" : "Gosodiadau",
    "Saving..." : "Yn cadw...",
    "seconds ago" : "eiliad yn ôl",
    "No" : "Na",
    "Yes" : "Ie",
    "Choose" : "Dewisiwch",
    "Ok" : "Iawn",
    "Cancel" : "Diddymu",
    "Shared" : "Rhannwyd",
    "Error" : "Gwall",
    "Error while sharing" : "Gwall wrth rannu",
    "Error while unsharing" : "Gwall wrth ddad-rannu",
    "Set expiration date" : "Gosod dyddiad dod i ben",
    "Expiration date" : "Dyddiad dod i ben",
    "Edit" : "Golygu",
    "Remove" : "Gwaredu",
    "Password" : "Cyfrinair",
    "Name" : "Enw",
    "Save" : "Cadw",
    "Sending ..." : "Yn anfon ...",
    "Email sent" : "Anfonwyd yr e-bost",
    "Email link to person" : "E-bostio dolen at berson",
    "Shared with you and the group {group} by {owner}" : "Rhannwyd â chi a'r grŵp {group} gan {owner}",
    "Shared with you by {owner}" : "Rhannwyd â chi gan {owner}",
    "group" : "grŵp",
    "Unshare" : "Dad-rannu",
    "can edit" : "yn gallu golygu",
    "create" : "creu",
    "delete" : "dileu",
    "access control" : "rheolaeth mynediad",
    "Share" : "Rhannu",
    "Resharing is not allowed" : "Does dim hawl ail-rannu",
    "Warning" : "Rhybudd",
    "Delete" : "Dileu",
    "Rename" : "Ailenwi",
    "The object type is not specified." : "Nid yw'r math o wrthrych wedi cael ei nodi.",
    "Add" : "Ychwanegu",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Methodd y diweddariad. Adroddwch y mater hwn i <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">gymuned ownCloud</a>.",
    "The update was successful. Redirecting you to ownCloud now." : "Roedd y diweddariad yn llwyddiannus. Cewch eich ailgyfeirio i ownCloud nawr.",
    "Personal" : "Personol",
    "Users" : "Defnyddwyr",
    "Apps" : "Pecynnau",
    "Admin" : "Gweinyddu",
    "Help" : "Cymorth",
    "Access forbidden" : "Mynediad wedi'i wahardd",
    "Create an <strong>admin account</strong>" : "Crewch <strong>gyfrif gweinyddol</strong>",
    "Username" : "Enw defnyddiwr",
    "Data folder" : "Plygell data",
    "Configure the database" : "Cyflunio'r gronfa ddata",
    "Database user" : "Defnyddiwr cronfa ddata",
    "Database password" : "Cyfrinair cronfa ddata",
    "Database name" : "Enw cronfa ddata",
    "Database tablespace" : "Tablespace cronfa ddata",
    "Database host" : "Gwesteiwr cronfa ddata",
    "Finish setup" : "Gorffen sefydlu",
    "Log out" : "Allgofnodi",
    "Search" : "Chwilio",
    "Log in" : "Mewngofnodi",
    "Alternative Logins" : "Mewngofnodiadau Amgen",
    "Use the following link to reset your password: {link}" : "Defnyddiwch y ddolen hon i ailosod eich cyfrinair: {link}",
    "New password" : "Cyfrinair newydd",
    "Reset password" : "Ailosod cyfrinair",
    "Imprint" : "Imprint"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
